;; Generated package description from dired-sidebar.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "dired-sidebar" "2.0.1.0.20260806.3" "Tree browser leveraging dired" '((emacs "29.1") (compat "30.0.0.0")) :commit "af43b8164191a6afb656a524c48010eb9e372c5d" :authors '(("James Nguyen" . "james@jojojames.com")) :maintainer '("James Nguyen" . "james@jojojames.com") :keywords '("dired" "files" "tools") :url "https://github.com/jojojames/dired-sidebar")
